@@ -27,7 +27,7 @@
 #' @param \dots Further arguments passed to or from other methods.
 #' @return { Returns CV score calculated for input parameters.  }
 #' @author Manuel Febrero-Bande, Manuel Oviedo de la Fuente
-#' \email{manuel.oviedo@@usc.es}
+#' \email{manuel.oviedo@@udc.es}
 #' @seealso See Also as \code{\link{optim.np}} \cr Alternative method:
 #' \code{\link{GCV.S}}
 #' @references Wasserman, L. \emph{All of Nonparametric Statistics}. Springer
@@ -68,7 +68,7 @@ CV.S=function (y, S, W = NULL, trim = 0, draw = FALSE, metric = metric.lp, ...)
         y.est <- fdata(y.est, y$argvals, y$rangeval, y$names)
         #e <- (      y - y.est)/(1-diag(S))
         e <- fdata(sweep((y - y.est)$data,2,1-diag(S),"%/%"), y$argvals, y$rangeval, y$names)
-        ee <- drop(norm.fdata(e, metric = metric, ...)[, 1]^2)
+        ee <- norm.fdata(e, metric = metric, ...)^2
         if (trim > 0) {
             e.trunc = quantile(ee, probs = (1 - trim), na.rm = TRUE, type = 4)
             ind <- ee <= e.trunc
