@@ -55,33 +55,33 @@ localMaxima <- function(x) {
 #' called.
 #' Model available options:
 #' \itemize{ 
-#' \item "lm": Step-wise lm regression model (uses lm function, stats
-#' package). Recommended for linear models, test linearity using
+#' \item \code{"lm"}: Step-wise lm regression model (uses lm function, stats
+#' package). Recommended for linear models, test linearity using.
 #' \code{\link{flm.test}} function.  
-#' \item "gam": Step-wise gam regression
-#' model (uses gam function, mgcv package). Recommended for non-linear models.
+#' \item \code{"gam"}: Step-wise gam regression model (uses gam function, mgcv package).
+#'  Recommended for non-linear models.
 #' }
 #' Models that use the indicated function of the required package: 
 #' \itemize{
-#' \item "svm": Support vector machine (svm function, e1071 package).#' 
-#' \item "knn": k-nearest neighbor regression (knnn.reg function, FNN package).#' 
-#' \item "lars": Least Angle Regression using Lasso (lars function, lars
-#' package). 
-#' \item "glmnet": Lasso and Elastic-Net Regularized Generalized Linear Models
-#' (glmnet and cv.glmnet function, glmnet package).  
-#' \item "rpart": Recursive partitioning for regression a (rpart function, rpart package).
-#' \item "flam": Fit the Fused Lasso Additive Model for a Sequence of Tuning
+##' \item \code{"svm"}: Support vector machine (svm function, e1071 package).
+#' \item \code{"knn"}: k-nearest neighbor regression (knnn.reg function, FNN package).
+#' \item \code{"lars"}: Least Angle Regression using Lasso (lars function, lars
+#' package).
+#' \item \code{"glmnet"}: Lasso and Elastic-Net Regularized Generalized Linear Models
+#' (glmnet and cv.glmnet function, glmnet package).
+#' \item \code{"rpart"}: Recursive partitioning for regression a (rpart function, rpart package).
+#' \item \code{"flam"}: Fit the Fused Lasso Additive Model for a Sequence of Tuning
 #' Parameters (flam function, flam package). 
-#' \item "novas": NOnparametric VAriable Selection (code available in
+#' \item \code{"novas"}: NOnparametric VAriable Selection (code available in
 #' \url{https://www.math.univ-toulouse.fr/~ferraty/SOFTWARES/NOVAS/novas-routines.R}).
-#' \item "cosso": Fit Regularized Nonparametric Regression Models Using COSSO
-#' Penalty (cosso function, cosso package).  
-#' \item "npreg": kernel regression estimate of a one (1) dimensional dependent
+#' \item \code{"cosso"}: Fit Regularized Nonparametric Regression Models Using COSSO
+#' Penalty (cosso function, cosso package). 
+#' \item \code{"npreg"}: kernel regression estimate of a one (1) dimensional dependent
 #'  variable on p-variate explanatory data (npreg function, np package). 
-#' \item "mars": Multivariate adaptive regression splines (mars function, mda
+#' \item \code{"mars"}: Multivariate adaptive regression splines (mars function, mda
 #' package). 
-#' \item "nnet": Fit Neural Networks (nnet function, nnet package). 
-#' \item"lars": Fits Least Angle Regression, Lasso and Infinitesimal Forward
+#' \item \code{"nnet"}:  Fit Neural Networks (nnet function, nnet package). 
+#' \item \code{"lars"}: Fits Least Angle Regression, Lasso and Infinitesimal Forward
 #' Stagewise regression models (lars function, lars package).  
 #' }
 #' 
@@ -108,20 +108,18 @@ localMaxima <- function(x) {
 #' used in do.call function like "what" argument.
 #' @param par.method List of parameters used to call the method. This argument
 #' is used in do.call function like "args" argument.
-#' @return LMDC.select function return a list of two elements:
-#' \itemize{
-#' \item \code{cor}{ the value of distance correlation for each covariate.} 
-#' \item \code{maxLocal}{ index or locations of local maxima distance correlations.}
-#' }
-#' LMDC.regre function return a list of folowing elements:
-#' \itemize{
-#' \item{model}{ object corresponding to the estimated method using the selected variables}
-#' \item{xvar}{ names of selected variables (impact points).} 
-#' \item{edf}{ Effective Degrees of Freedom.} 
-#' \item{nvar}{Number of selected variables (impact points).}
-#' }
+#' @return 
+#' \item{\code{LMDC.select}}{ function returns a list of two elements:}
+#' \item{\code{cor}}{ the value of distance correlation for each covariate.} 
+#' \item{\code{maxLocal}}{ index or locations of local maxima distance correlations.} 
+#' \item{\code{LMDC.regre}}{ function returns a list of folowing elements:}
+#' \item{\code{model}}{ object corresponding to the estimated method using the selected variables.}
+#' \item{\code{xvar}}{ names of selected variables (impact points).}
+#' \item{\code{edf}}{ effective degrees of freedom.}
+#' \item{\code{nvar}}{ number of selected variables (impact points).}
+#' 
 #' @author Manuel Oviedo de la Fuente \email{manuel.oviedo@@udc.es}
-#' @seealso See Also as: \code{\link{lm}}, \code{\link{gam}},
+#' @seealso See Also as: \link[stats]{lm}, \link[mgcv]{gam},
 #' \code{\link{dcor.xy}}.
 #' @references Ordonez, C., Oviedo de la Fuente, M., Roca-Pardinas, J.,
 #' Rodriguez-Perez, J. R. (2018). Determining optimum wavelengths for leaf
@@ -129,6 +127,7 @@ localMaxima <- function(x) {
 #' \emph{Chemometrics and Intelligent Laboratory Systems}. 173,41-50
 #' \doi{10.1016/j.chemolab.2017.12.001}.
 #' @keywords regression
+# @importFrom mgcv gam gam.fit bam s te t2
 #' @examples
 #' \dontrun{
 #' data(tecator)
@@ -235,7 +234,7 @@ LMDC.select <- function(y, covar, data, tol = .06, pvalue = .05,
 #######################################################
 
 #######################################################
-# Argurments
+# Arguments
 # y: name of the response variable
 # covar: vector with the names of the predictor variables
 # data: data frame for model estimation  (data train)
@@ -269,7 +268,7 @@ LMDC.select <- function(y, covar, data, tol = .06, pvalue = .05,
 
 #######################################################
 #' @rdname LMDC.select
-#' @export
+#' @export 
 LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
                        method="lm", par.method = NULL,
                        plot=FALSE,verbose=FALSE){
@@ -319,7 +318,7 @@ LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
       }
     else k <- 4
     ff<-as.formula(ff)
-    model0 <- gam(ff,data=data)
+    model0 <- mgcv::gam(ff,data=data)
     par.method2 <- list("formula"=ff,"data"= data)
     par.method<-c(par.method2,par.method)
    for (i in 1:nvar) {
@@ -328,7 +327,10 @@ LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
       xvar2<- c(xvar,xentra)   
       ff<-as.formula(paste(y,"~",paste("s(",xvar2,",k=",k,")",collapse="+"),collapse=""))
       par.method$formula<-ff
-      if (verbose)  {print("gam");    print(1);print(ff)}
+      if (verbose)  { 
+        print("gam");    
+        #print(1);print(ff)
+        }
       model <- do.call(method,par.method)
         if (rev(summary(model)$s.table[,"p-value"])[1]<pvalue){
         if (verbose)  { print("entra");print(xentra);print(summary(model))}
@@ -349,7 +351,6 @@ LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
   }
   if (method == "rpart"){
     ff<-as.formula(paste(y,"~",paste(covar,collapse="+"),collapse=""))
-    #model0 <- rpart(ff, data = data)
     par.method$formula <- ff
     par.method$data <- data
     model0 <- do.call(method,par.method)
@@ -442,7 +443,6 @@ LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
   }
   if (method == "npreg"){
     #ff<-as.formula(paste(y,"~",paste(covar,collapse="+"),collapse=""))
-    #model0 <- rpart(ff, data = data)
     #par.method$formula <- ff
     #par.method$data <- data
     par.method$txdat<-data[,covar,drop=F]
@@ -493,5 +493,3 @@ LMDC.regre <- function(y,covar,data,newdata,pvalue=.05,
   return(list(model=model0, xvar=xvar, pred=pred0,edf=edf,nvar=nvar))     
 }  
 ################################################################################
-################################################################################
-
