@@ -3,10 +3,11 @@
 ##############################################
 fregre.gsam.cv<-function(data, y, x, family = gaussian()
                          , alpha = 0.05, type.basis = "pc"
-                         , ncomp = 8, ncomp.fix = TRUE
+                         , numbasis = 8, numbasis.opt = TRUE
                          , par.basis=list(), kbs, par.model){
   #0-
-#  print("eeentra CV")
+ # print("eeentra gsam.cv")
+  
   if (missing(y)) {stop("Please, specify the name of the response variable")  }
   #if (missing(alpha)) alpha<-.05
   if (missing(par.model)) par.model<-list() 
@@ -48,25 +49,33 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
   ipredictors<-numeric(npredictors)
   names(ipredictors)<- setdiff(names(ldata0),resp)
   xentra <- x
-  tbasis <-  type.basis
+  
   iposibles<-xposibles<-NULL
   xdata<-NULL
   xposibles <- c(infunc)
   xdata<-cbind(data$df[,c(y,infunc),drop=F])
   lenfunc <- ifelse(length(ifunc)==0,FALSE,TRUE)
+  tbasis <- type.basis
+  if (type.basis %in% c("fourier","bspline")) 
+    {
+    tbasis="basis"
+    k <- min(5,numbasis)
+    if (numbasis<5) warning("Numbasis has been increased to 5")
+  }
+  
   if (lenfunc){
     for (i in 1:length(ifunc)){
     switch(tbasis,"pc"={
-          basis1<-create.pc.basis(ldata0[[ifunc[i]]],1:ncomp)
-          icomp <- colnames(basis1$x)
+          basis1<-create.pc.basis(ldata0[[ifunc[i]]],1:numbasis)
+          icomp <- colnames(basis1$coefs)
         },
         "pls"={
-          basis1<-create.pls.basis(ldata0[[ifunc[i]]],ldata0[[y]],1:ncomp)
-          icomp <- colnames(basis1$x)
+          basis1<-create.pls.basis(ldata0[[ifunc[i]]],ldata0[[y]],1:numbasis)
+          icomp <- colnames(basis1$coefs)
         },"basis"={
-          ncomp.fix=TRUE
+          numbasis.opt=TRUE
           basis1<-create.fdata.basis(ldata0[[ifunc[i]]],
-                                     1:ncomp)
+                                     1:numbasis,type.basis=type.basis)
           xx <- fdata.cen(ldata0[[ifunc[i]]])
           xmean = xx[[2]]
           xcen = xx[[1]]
@@ -74,16 +83,13 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
                          y = t(xcen$data), 
                          basisobj = basis1)
           
-          basis1$x = t(x.fd$coefs)          
-        #  print(dim(basis1$x ))
+          basis1$coefs = t(x.fd$coefs)          
           icomp <-  basis1$names
-          print(icomp)
-      }
+          }
     )
-#print(paste(ifunc[i],".",colnames(basis1$x),sep="") )
-    colnames(basis1$x)<-paste(ifunc[i],".",icomp,sep="") 
-    xposibles <- c(xposibles,colnames(basis1$x)[1:ncomp])
-      xdata<-cbind(xdata,basis1$x[,1:ncomp,drop=F])
+    colnames(basis1$coefs)<-paste(ifunc[i],".",icomp,sep="") 
+    xposibles <- c(xposibles,colnames(basis1$coefs)[1:numbasis])
+      xdata<-cbind(xdata,basis1$coefs[,1:numbasis,drop=F])
     }
   }
   iposibles<-1:length(xposibles)
@@ -93,11 +99,11 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
   nam.model<-"gam"    
   par.model<-list()
   ibest <- 1
-  k <- 1
+
   form.ini <-  paste(y,"~ 1")
   # print("best.model")
   best.model <- gam(as.formula(form.ini),data=xdata,family=family)#,weights=weights)
-  #print("best.model");  print(best.model)
+  # print("best.model");  print(best.model)
   nvar <- 1
   res<-NULL
   best.aic<-Inf
@@ -107,12 +113,12 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
     # print("while");  print(nvar)
     imax <- 1:(maxvar-nvar+1)
     form.nl <- form.ini
-    lmax<-length(imax)
-    aic<-numeric(lmax)
+    lmax <- length(imax)
+    aic <- numeric(lmax)
     for (k in 1:lmax) {  
     #   print(k)
     #  print(xposibles[k])
-    if (ncomp.fix) ik<-1:k
+    if (numbasis.opt) ik<-1:k
     else ik<-k
        if (is.factor(xdata[[xposibles[k]]]))
          fpredictors.nl <- paste("~.+",xposibles[k],sep="",collapse="+")
@@ -124,6 +130,7 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
        #as.formula(form.ini,fpredictors.nl)
        par.model$formula<-form.nl #as.formula(form.nl)
        par.model$data<-xdata
+       par.model$family<- family
        res[[k]]<-do.call(nam.model,par.model)             
        
        aic[k] <- res[[k]]$gcv.ubre
@@ -142,7 +149,7 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
         #else best.aic<-aic[posible.aic]  
       best.aic <- aic[posible.aic]
       best.model <- res[[posible.aic]]
-      if (ncomp.fix){
+      if (numbasis.opt){
         nvar <- posible.aic
         xmodelo <- c(xmodelo,xposibles[1:posible.aic]) 
         imodelo <- c(imodelo,iposibles[1:posible.aic]) 
@@ -150,14 +157,14 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
         iposibles <- iposibles[-c(1:posible.aic)]
       } else {
         xmodelo <- c(xmodelo,xposibles[posible.aic]) 
-        imodelo <-c(imodelo,iposibles[posible.aic]) 
+        imodelo <- c(imodelo,iposibles[posible.aic]) 
         xposibles <- xposibles[-posible.aic]
         iposibles <- iposibles[-posible.aic]
       }
       form.ini <-   res[[posible.aic]]$formula
       }    else {      parar=TRUE    }
     #cat("nvar");print(nvar)
-    if (nvar==ncomp) {      parar=TRUE    }    else { nvar<- nvar+1}
+    if (nvar==numbasis) {      parar=TRUE    }    else { nvar<- nvar+1}
   } else {     parar=TRUE    }
 } #fin while
  #para PC
@@ -168,24 +175,24 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
  #basis1$basis<- basis1$basis#[imodelo,,drop=F]
  vs.list[[vfunc[i]]] = basis1$basis
  mean.list[[vfunc[i]]] = basis1$mean
- JJ = NULL
+ #JJ = NULL
  z <- best.model
  if (lenfunc) {
    z$mean = mean.list
    z$basis.x[[vfunc[i]]] = basis1
-   z$basis.b[[vfunc[i]]] = basis1
-   z$JJ <- JJ
+   #z$basis.b[[vfunc[i]]] = basis1
+   #z$JJ <- JJ
    z$vs.list = vs.list
    z$vfunc <- vfunc
-   colnames(z$basis.x[[vfunc[i]]]$x)<-paste("PC",1:ncol(z$basis.x[[vfunc[i]]]$x),sep="")
+   colnames(z$basis.x[[vfunc[i]]]$coefs)<-paste("PC",1:ncol(z$basis.x[[vfunc[i]]]$coefs),sep="")
  }
- #print("finnn")
+ # print("finnn")
  if (is.null(imodelo)) {
    warning("No component of the variable is significant") 
  }
  #else{
  
-  z$ncomp.opt<-imodelo
+  z$numbasis.opt<-imodelo
   z$formula <- as.formula(z$formula) 
   z$formula.ini =    as.formula( paste(y,"~+s(",x,",k=",kbs,")",sep=""))
 # print(summary(z)); print(z$formula) ; print(z$formula.ini) 
@@ -198,45 +205,3 @@ fregre.gsam.cv<-function(data, y, x, family = gaussian()
  return(z)
 }
 ###################################################
-#sp<-fda.usc:::sp
-#pvalue.anova<-fda.usc:::pvalue.anova
- # res.gsam.cv<-fregre.gsam.cv(la,resp,alpha=0.05,
- #                             type.basis="basis",
- #                             criterio="sp",ncomp=5)
- # summary(res.gsam.cv)
- # 
- # pr<-predict.fregre.gsam(res.gsam.cv,la)
- # 
- # res.gsam.cv<-fregre.gsam.cv(la,resp,alpha=0.05,
- #                             type.basis="pc",
- #                             criterio="sp",ncomp=8)
- # summary(res.gsam.cv)
- #  class(res.gsam.cv) 
- #  names(res.gsam.cv)
- #  res.gsam.cv$
- #  pr<-predict.fregre.gsam(res.gsam.cv,la)
- # 
-# res.gsam.cv<-fregre.gsam.cv(la,resp,
-#                             c("x1","x2","x"),ncomp=2)
-# summary(res.gsam.cv)
-# 
-# 
-# res.gsam.cv<-fregre.gsam.cv(la,resp,c("xcat0","xcat2" ,"xcat1"),alpha=0.05,
-#                             type.basis="pc",
-#                             criterio="sp",ncomp=2)
-# summary(res.gsam.cv)
-# 
-# 
-# 
-# resp<-"y"
-# res.gsam.cv<-fregre.gsam.cv(la,resp,c("x1","x2","x"),alpha=0.05,
-#                             type.basis="pc",
-#                             criterio="sp",ncomp=8)
-# summary(res.gsam.cv)
-# 
-# 
-# res.gsam.cv<-fregre.gsam.cv(la,resp,alpha=0.05,
-#                             type.basis="pc",
-#                             criterio="sp",ncomp=8)
-# summary(res.gsam.cv)
-# 
