@@ -1,4 +1,5 @@
-outliers.depth.pond<-function(fdataobj,nb=200,smo=0.05,quan=0.5,dfunc=depth.mode,...){
+outliers.depth.pond <- function(fdataobj,nb=200,smo=0.05,
+                                quan=0.5,dfunc=depth.mode,...){
 if (!is.fdata(fdataobj)) fdataobj=fdata(fdataobj)
  nas1<-is.na.fdata(fdataobj)
  if (any(nas1))  stop("fdataobj contain ",sum(nas1)," curves with some NA value \n")
@@ -9,7 +10,7 @@ n<-nrow(fdataobj)
 m<-ncol(fdataobj)
 if (is.null(n) && is.null(m)) stop("ERROR IN THE DATA DIMENSIONS")
 if (is.null(row.names(fdataobj[["data"]]))) row.names(fdataobj[["data"]])=1:n
-cutoff<-quantile(quantile.outliers.pond(x,dfunc=dfunc,nb=nb,smo=smo,...),probs=quan)
+cutoff<-quantile(quantile_outliers_pond(x,dfunc=dfunc,nb=nb,smo=smo,...),probs=quan)
     hay<-1
     outliers<-dep.out<-ite<-c()
     curvasgood<-fdataobj
