@@ -19,7 +19,7 @@
 #' \code{"names"}: (optional) list with \code{main} an overall title,
 #' \code{xlab} title for \code{x} axis and \code{ylab} title for \code{y} axis.
 #' } 
-#' or a two-argument functional data object, see \code{\link{bifd}}.
+#' or a two-argument functional data object, see \link[fda]{bifd}.
 #' @param type 1-character string giving the type of plot desired.\cr The
 #' following values are possible for \code{fdata} class object: "l" for lines
 #' (by default),"p" for points, , "o" for overplotted points and lines, "b",
@@ -51,6 +51,8 @@
 #' @param trim The alpha of the trimming.
 #' @param levgray A vector of desired gray levels between 0 and 1; zero
 #' indicates "black" and one indicates "white".
+#' @param ask Logical. If \code{TRUE}, prompts for user interaction with the current graphics device.
+#' @param col  The colors for curves, lines and points.
 #' @author Manuel Febrero Bande and Manuel Oviedo de la Fuente
 #' <manuel.oviedo@@udc.es>
 #' @seealso See Also as \code{\link{fdata}}
@@ -86,107 +88,107 @@
 #' @export
 #' @export plot.fdata
 plot.fdata<-function(x,type,main,xlab,ylab,lty=1,mfrow=c(1,1),time=1,...) {
-#if (missing(lty)) lty = par.fda.usc$lty
-if (inherits(x,"fdata2d"))  {
-#stop("Object is not fdata2d class")
-if (missing(type)) type="image.contour"
-#if (missing(main)) main=x[["names"]][["main"]]
-#if (missing(xlab)) xlab=x[["names"]][["xlab"]]
-#if (missing(ylab)) ylab=x[["names"]][["ylab"]]
-dm<-dim(x$data)
-j<-1
-len.dm<-length(dm)
-rng<-range(x$data)
-#if (!ask) {
-#   if (dm[1]>9)  ask=TRUE
-#   else {
-#       ask=FALSE
-#       if (dm[1]==1) par(mfrow=c(1,1),ask=FALSE) 
-#       if (dm[1]==2) par(mfrow=c(1,2),ask=FALSE)        
-#       if (dm[1]==3) par(mfrow=c(1,3),ask=FALSE)        
-#       if (dm[1]==4) par(mfrow=c(2,2),ask=FALSE)        
-#       if (dm[1]>4) par(mfrow=c(2,3),ask=FALSE)                             
-#       if (dm[1]>6) par(mfrow=c(3,3),ask=FALSE)                                    
-#   }}
-par(mfrow=mfrow)
-#npar<-par()$mfrow[1]*par()$mfrow[2]
-npar<-mfrow[1]*mfrow[2]
-for (i in 1:dm[1]) {
-#if (ask) {   par(mfrow=c(1,1),ask=ask)     }
-z <- x[["data"]][i,,]
-if (len.dm==3) {
-  if (missing(main))  main <- paste(x$names$main," ",dimnames(x$data)[[1]][i],sep="")
-  if (missing(xlab))  xlab <- x$names$xlab[1]
-  if (missing(ylab)) ylab =  x$names$xlab[2]
-  
-  switch (type,
-  "persp"={                          
-  par(bg = "white")
-  xx <- x[["argvals"]][[1]]
-  y <- x[["argvals"]][[2]]
-  
-  
-  #nrz <- nrow(z);
-  #ncz <- ncol(z)
-  #jet.colors <- colorRampPalette( c("yellow", "red") ) 
-  #nbcol <- length(xx)
-  #color <- jet.colors(nbcol)
-  #zfacet <- z[-1, -1] + z[-1, -ncz] + z[-nrz, -1] + z[-nrz, -ncz]
-  #facetcol <- cut(zfacet, nbcol)
-  
-   persp(x=xx,y=y,z=z,xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],zlim=rng,
-   main = ,xlab = xlab, ylab =  ylab,...) 
-  # main =  x$names$main[i],xlab = x$names$xlab[1], ylab =  x$names$xlab[2],...)
-  #, col=color[facetcol],...)
-  # par(op)
-  },
-  "filled.contour"={
-  filled.contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,
-  xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],
-  plot.title=title(main = main, xlab =xlab, ylab =ylab),...)},
-  
-  "contour"={
-    contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,zlim=rng,
-  xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],
-  plot.title=title(main =  main, xlab = xlab, ylab = ylab),...)},#labels repetidos
+  #if (missing(lty)) lty = par.fda.usc$lty
+  if (inherits(x,"fdata2d"))  {
+    #stop("Object is not fdata2d class")
+    if (missing(type)) type="image.contour"
+    #if (missing(main)) main=x[["names"]][["main"]]
+    #if (missing(xlab)) xlab=x[["names"]][["xlab"]]
+    #if (missing(ylab)) ylab=x[["names"]][["ylab"]]
+    dm<-dim(x$data)
+    j<-1
+    len.dm<-length(dm)
+    rng<-range(x$data)
+    #if (!ask) {
+    #   if (dm[1]>9)  ask=TRUE
+    #   else {
+    #       ask=FALSE
+    #       if (dm[1]==1) par(mfrow=c(1,1),ask=FALSE) 
+    #       if (dm[1]==2) par(mfrow=c(1,2),ask=FALSE)        
+    #       if (dm[1]==3) par(mfrow=c(1,3),ask=FALSE)        
+    #       if (dm[1]==4) par(mfrow=c(2,2),ask=FALSE)        
+    #       if (dm[1]>4) par(mfrow=c(2,3),ask=FALSE)                             
+    #       if (dm[1]>6) par(mfrow=c(3,3),ask=FALSE)                                    
+    #   }}
+    par(mfrow=mfrow)
+    #npar<-par()$mfrow[1]*par()$mfrow[2]
+    npar<-mfrow[1]*mfrow[2]
+    for (i in 1:dm[1]) {
+      #if (ask) {   par(mfrow=c(1,1),ask=ask)     }
+      z <- x[["data"]][i,,]
+      if (len.dm==3) {
+        if (missing(main))  main <- paste(x$names$main," ",dimnames(x$data)[[1]][i],sep="")
+        if (missing(xlab))  xlab <- x$names$xlab[1]
+        if (missing(ylab)) ylab =  x$names$xlab[2]
+        
+        switch (type,
+                "persp"={                          
+                  par(bg = "white")
+                  xx <- x[["argvals"]][[1]]
+                  y <- x[["argvals"]][[2]]
+                  
+                  
+                  #nrz <- nrow(z);
+                  #ncz <- ncol(z)
+                  #jet.colors <- colorRampPalette( c("yellow", "red") ) 
+                  #nbcol <- length(xx)
+                  #color <- jet.colors(nbcol)
+                  #zfacet <- z[-1, -1] + z[-1, -ncz] + z[-nrz, -1] + z[-nrz, -ncz]
+                  #facetcol <- cut(zfacet, nbcol)
+                  
+                  persp(x=xx,y=y,z=z,xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],zlim=rng,
+                        main = ,xlab = xlab, ylab =  ylab,...) 
+                  # main =  x$names$main[i],xlab = x$names$xlab[1], ylab =  x$names$xlab[2],...)
+                  #, col=color[facetcol],...)
+                  # par(op)
+                },
+                "filled.contour"={
+                  filled.contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,
+                                 xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],
+                                 plot.title=title(main = main, xlab =xlab, ylab =ylab),...)},
+                
+                "contour"={
+                  contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,zlim=rng,
+                          xlim=x[["rangeval"]][[1]],ylim=x[["rangeval"]][[2]],
+                          plot.title=title(main =  main, xlab = xlab, ylab = ylab),...)},#labels repetidos
+                
+                "image"={
+                  image(x = x[["argvals"]][[1]],y = x[["argvals"]][[2]],z=z,
+                        xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],zlim=rng,
+                        main = main, xlab = xlab, ylab = ylab,...)},
+                "image.contour"={
+                  image(x = x[["argvals"]][[1]],y = x[["argvals"]][[2]],z=z,
+                        xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],zlim=rng,
+                        main = main,    xlab = xlab, ylab =  ylab,...)
+                  contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,add = TRUE, drawlabels = FALSE,...)
+                }#lattice plot    
+                #"contourplot"={contourplot(data=z,
+                #xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],...)}    
+        )
+      }
       
-  "image"={
-    image(x = x[["argvals"]][[1]],y = x[["argvals"]][[2]],z=z,
-  xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],zlim=rng,
-  main = main, xlab = xlab, ylab = ylab,...)},
-  "image.contour"={
-    image(x = x[["argvals"]][[1]],y = x[["argvals"]][[2]],z=z,
-  xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],zlim=rng,
-  main = main,    xlab = xlab, ylab =  ylab,...)
-      contour(x=x[["argvals"]][[1]],y=x[["argvals"]][[2]],z=z,add = TRUE, drawlabels = FALSE,...)
-      }#lattice plot    
-  #"contourplot"={contourplot(data=z,
-  #xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],...)}    
-  )
-}
-
-if (names(dev.cur())!="pdf" & j==npar) {
-   Sys.sleep(time)
-   j<-1
-   }
-else j<-j+1   
-}  
-#else {
-#  if (len.dm==3) { contourplot(data=z,
-#xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],...)}
-#    }
-if (len.dm>3) stop("Not implemented plot for arrays of more than 3 dimension yet")
-}
-else {
-if (!is.fdata(x))  stop("Object is not fdata class")
-if (missing(type)) type="l"
-if (missing(main)) main=x[["names"]][["main"]]
-if (missing(xlab)) xlab=x[["names"]][["xlab"]]
-if (missing(ylab)) ylab=x[["names"]][["ylab"]]
-
-if (is.vector(x[["data"]])) fda::matplot(x[["argvals"]],(x[["data"]]),type=type,lty=lty,main=main,ylab=ylab,xlab=xlab,...)
-else fda::matplot(x[["argvals"]],t(x[["data"]]),type=type,lty=lty,main=main,ylab=ylab,xlab=xlab,...)
-}
+      if (names(dev.cur())!="pdf" & j==npar) {
+        Sys.sleep(time)
+        j<-1
+      }
+      else j<-j+1   
+    }  
+    #else {
+    #  if (len.dm==3) { contourplot(data=z,
+    #xlim = x[["rangeval"]][[1]],ylim = x[["rangeval"]][[2]],...)}
+    #    }
+    if (len.dm>3) stop("Not implemented plot for arrays of more than 3 dimension yet")
+  }
+  else {
+    if (!is.fdata(x))  stop("Object is not fdata class")
+    if (missing(type)) type="l"
+    if (missing(main)) main=x[["names"]][["main"]]
+    if (missing(xlab)) xlab=x[["names"]][["xlab"]]
+    if (missing(ylab)) ylab=x[["names"]][["ylab"]]
+    
+    if (is.vector(x[["data"]])) fda::matplot(x[["argvals"]],(x[["data"]]),type=type,lty=lty,main=main,ylab=ylab,xlab=xlab,...)
+    else fda::matplot(x[["argvals"]],t(x[["data"]]),type=type,lty=lty,main=main,ylab=ylab,xlab=xlab,...)
+  }
 }
 
 #' @rdname plot.fdata
@@ -204,12 +206,12 @@ lines.fdata = function (x, ...)
 #' @rdname plot.fdata
 #' @export
 title.fdata<-function(x,main=NULL,xlab=NULL,ylab=NULL,rownames=NULL) {
-if (!is.fdata(x))  stop("Object is not fdata class")
-if (!is.null(rownames)) rownames(x[["data"]])<-rownames
-if (!is.null(main)) x[["names"]][["main"]]<-main
-if (!is.null(xlab)) x[["names"]][["xlab"]]<-xlab
-if (!is.null(ylab)) x[["names"]][["ylab"]]<-ylab
-x
+  if (!is.fdata(x))  stop("Object is not fdata class")
+  if (!is.null(rownames)) rownames(x[["data"]])<-rownames
+  if (!is.null(main)) x[["names"]][["main"]]<-main
+  if (!is.null(xlab)) x[["names"]][["xlab"]]<-xlab
+  if (!is.null(ylab)) x[["names"]][["ylab"]]<-ylab
+  x
 }
 
 
@@ -331,7 +333,7 @@ plot.depth<-function(x,trim, levgray=.9,...){
 }
 
 ############################################ Auxiliar functions
-image.scale <- function(z, zlim, col = heat.colors(12),
+image_scale <- function(z, zlim, col = heat.colors(12),
                         breaks, horiz=TRUE, ylim=NULL, xlim=NULL, ...){
   if(!missing(breaks)){
     if(length(breaks) != (length(col)+1)){stop("must have one more break than colour")}
@@ -400,7 +402,7 @@ color.bar <- function(colores, min, max=-min, nticks=length(colores)+1,
   }
 }
 
-        
+
 #' @rdname plot.fdata
 #' @export
 plot.bifd<-function(x,argvals.s,argvals.t,...){
@@ -450,4 +452,45 @@ plot.bifd<-function(x,argvals.s,argvals.t,...){
 #     }
 #     plot.fdata(lfdata[[idat]], col =  color2, main =nam[idat],...)
 #   }
-# }
\ No newline at end of file
+# }
+
+
+
+
+#' @rdname plot.fdata
+#' @export plot.lfdata
+plot.lfdata<-function(x, ask=FALSE, col,...){
+  mf=5
+  nvar<-length(x)
+  if (nvar>4) ask=TRUE
+  if (ask) {par(mfrow = c(1, 1))
+    dev.interactive()
+    oask <- devAskNewPage(TRUE)
+    on.exit(devAskNewPage(oask))}
+  else{    mf<-switch(nvar,
+                      "1"={c(1,1)},
+                      "2"={c(1,2)},
+                      "3"={c(1,3)},
+                      "4"={c(2,2)})            
+  par(mfrow =mf)                    }
+  names1<-names2<-names<-x[[1]][["names"]]
+  names1$main<-"Multivariate Functional Data"
+  #    tr<-paste("mode.tr",trim*100,"\u0025",sep="")         
+  nam <- names(x)
+  if (is.null(nam)) nam<-1:nvar
+  nam2 <- setdiff(nam,"df")
+  for (idat in nam2) {
+    data <- x[[idat]]$data
+    tt <- x[[idat]]$argvals
+    rtt <- x[[idat]]$rangeval
+    if (missing(col)) col2 <- 1
+    else {
+      if (is.list(col)) col2<- col[[idat]]
+      else col2<-col
+    }
+    plot.fdata(x[[idat]], col =  col2, main =idat,...)
+  }
+  
+}
+
+
