@@ -1,6 +1,7 @@
-plot.lfdata<-function(lfdata,ask=FALSE,color,...){
+#' @export plot.lfdata
+plot.lfdata<-function(x,ask=FALSE, col,...){
   mf=5
-  nvar<-length(lfdata)
+  nvar<-length(x)
   if (nvar>4) ask=TRUE
   if (ask) {par(mfrow = c(1, 1))
             dev.interactive()
@@ -12,22 +13,22 @@ plot.lfdata<-function(lfdata,ask=FALSE,color,...){
                       "3"={c(1,3)},
                       "4"={c(2,2)})            
            par(mfrow =mf)                    }
-  names1<-names2<-names<-lfdata[[1]][["names"]]
+  names1<-names2<-names<-x[[1]][["names"]]
   names1$main<-"Multivariate Functional Data"
   #    tr<-paste("mode.tr",trim*100,"\u0025",sep="")         
-  nam<-names(lfdata)
+  nam<-names(x)
   
   if (is.null(nam)) nam<-1:nvar
   for (idat in 1:nvar) {
-    data<-lfdata[[idat]]$data
-    tt<-lfdata[[idat]]$argvals
-    rtt<-lfdata[[idat]]$rangeval
-    if (missing(color)) color2<-1
+    data<-x[[idat]]$data
+    tt<-x[[idat]]$argvals
+    rtt<-x[[idat]]$rangeval
+    if (missing(col)) col2<-1
     else {
-      if (is.list(color)) color2<-color[[idat]]
-      else color2<-color
+      if (is.list(col)) col2<-col[[idat]]
+      else col2<-col
     }
-    plot.fdata(lfdata[[idat]], col =  color2, main =nam[idat],...)
+    plot.fdata(x[[idat]], col =  col2, main =nam[idat],...)
   }
   
 }
\ No newline at end of file
